The Multiple on Invested Capital (MOIC) measures the performance of an
investment today relative to the initial investment.

Formula: (Realized investment + Unrealized investment) / Initial Investment

Unrealised value, also referred to as residual value (or NAV), is the total
value of the remaining portfolio’s active investments that have not yet been
liquidated.

See also:
- <https://www.moonfare.com/glossary/multiple-on-invested-capital-moic>
- <https://financestu.com/tvpi-vs-moic/>
